//
// Implementation of a 32-bit KISS generator which uses no multiply instructions
// and no unsigned or 64 bit arithemtic.
// Originally by David Jones of the UCL Bioinformatics Group.
// 
// Modified by M.Rychlik to actually use unsigneds for x, y, z, w and c
// which also demands adding a masking operation when shifting y to the right.
//
#include <stdio.h>

// Dave's original declarations:
// static unsigned int x=123456789,y=234567891,z=345678912,w=456789123,c=0;
int x = 123456789;
int y = 234567891;
int z = 345678912;
int w = 456789123;
int c = 0;

unsigned int JKISS32()
{
	int t;

	y ^= (y <<  5);
	y ^= (y >>  7) & ~0xfe000000;
	y ^= (y << 22);
	t = z + w + c;
        z = w;
        c = t < 0;
        w = t & 2147483647;
	x += 1411392427;
	return (x + y + w);
}


int main (int argc, char* argv[])
{
	int i;
	int random;

	for (i = 0; i < 20; i++)
	{
		random = JKISS32();
		printf ("%x\n", random);
	}
	return(0);
}

